@@ -26,10 +26,10 @@ import greenlet
 from gunicorn.workers.base_async import AsyncWorker
 
 
-def _eventlet_sendfile(fdout, fdin, offset, nbytes):
+def _eventlet_sendfile(fdout, fdin, offset, nbytes, _os_sendfile=os.sendfile):
     while True:
         try:
-            return os.sendfile(fdout, fdin, offset, nbytes)
+            return _os_sendfile(fdout, fdin, offset, nbytes)
         except OSError as e:
             if e.args[0] == errno.EAGAIN:
                 trampoline(fdout, write=True)
