@@ -4,42 +4,30 @@
 # See the NOTICE for more information.
 
 # design:
-# a threaded worker accepts connections in the main loop, accepted
-# connections are are added to the thread pool as a connection job. On
-# keepalive connections are put back in the loop waiting for an event.
-# If no event happen after the keep alive timeout, the connectoin is
+# A threaded worker accepts connections in the main loop, accepted
+# connections are added to the thread pool as a connection job.
+# Keepalive connections are put back in the loop waiting for an event.
+# If no event happen after the keep alive timeout, the connection is
 # closed.
+# pylint: disable=no-else-break
 
-from collections import deque
-from datetime import datetime
+import concurrent.futures as futures
 import errno
-from functools import partial
 import os
+import selectors
 import socket
 import ssl
 import sys
-from threading import RLock
 import time
+from collections import deque
+from datetime import datetime
+from functools import partial
+from threading import RLock
 
-from .. import http
-from ..http import wsgi
-from .. import util
 from . import base
-from .. import six
-
-
-try:
-    import concurrent.futures as futures
-except ImportError:
-    raise RuntimeError("""
-    You need to install the 'futures' package to use this worker with this
-    Python version.
-    """)
-
-try:
-    from asyncio import selectors
-except ImportError:
-    from gunicorn import selectors
+from .. import http
+from .. import util
+from ..http import wsgi
 
 
 class TConn(object):
@@ -74,16 +62,11 @@ class TConn(object):
     def close(self):
         util.close(self.sock)
 
-    def __lt__(self, other):
-        return self.timeout < other.timeout
-
-    __cmp__ = __lt__
-
 
 class ThreadWorker(base.Worker):
 
     def __init__(self, *args, **kwargs):
-        super(ThreadWorker, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.worker_connections = self.cfg.worker_connections
         self.max_keepalived = self.cfg.worker_connections - self.cfg.threads
         # initialise the pool
@@ -103,10 +86,14 @@ class ThreadWorker(base.Worker):
                     "Check the number of worker connections and threads.")
 
     def init_process(self):
-        self.tpool = futures.ThreadPoolExecutor(max_workers=self.cfg.threads)
+        self.tpool = self.get_thread_pool()
         self.poller = selectors.DefaultSelector()
         self._lock = RLock()
-        super(ThreadWorker, self).init_process()
+        super().init_process()
+
+    def get_thread_pool(self):
+        """Override this method to customize how the thread pool is created"""
+        return futures.ThreadPoolExecutor(max_workers=self.cfg.threads)
 
     def handle_quit(self, sig, frame):
         self.alive = False
@@ -179,6 +166,9 @@ class ThreadWorker(base.Worker):
                     except EnvironmentError as e:
                         if e.errno != errno.EBADF:
                             raise
+                    except KeyError:
+                        # already removed by the system, continue
+                        pass
 
                 # close the socket
                 conn.close()
@@ -208,7 +198,7 @@ class ThreadWorker(base.Worker):
             if self.nr_conns < self.worker_connections:
                 # wait for an event
                 events = self.poller.select(1.0)
-                for key, mask in events:
+                for key, _ in events:
                     callback = key.data
                     callback(key.fileobj)
 
@@ -227,7 +217,7 @@ class ThreadWorker(base.Worker):
             if not self.is_parent_alive():
                 break
 
-            # hanle keepalive timeouts
+            # handle keepalive timeouts
             self.murder_keepalived()
 
         self.tpool.shutdown(False)
@@ -240,6 +230,7 @@ class ThreadWorker(base.Worker):
 
     def finish_request(self, fs):
         if fs.cancelled():
+            self.nr_conns -= 1
             fs.conn.close()
             return
 
@@ -272,7 +263,7 @@ class ThreadWorker(base.Worker):
         keepalive = False
         req = None
         try:
-            req = six.next(conn.parser)
+            req = next(conn.parser)
             if not req:
                 return (False, conn)
 
@@ -346,7 +337,7 @@ class ThreadWorker(base.Worker):
                 return False
         except EnvironmentError:
             # pass to next try-except level
-            six.reraise(*sys.exc_info())
+            util.reraise(*sys.exc_info())
         except Exception:
             if resp and resp.headers_sent:
                 # If the requests have already been sent, we should close the
